@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # Netsink - Network Sinkhole for Isolated Malware Analysis
-# Copyright (C) 2014 Steve Henderson
+# Copyright (C) 2013-2014 Steve Henderson
 # 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@ import sys
 import threading
 import time
 
-from netsink.config import Config, ModuleConfig
+from netsink.config import Config, ModuleConfig, parseints
 from netsink.listener import Listener
 from netsink.modules import registry
 from netsink.redirection import Redirector
@@ -78,9 +78,9 @@ def redirection(config, listeners):
     for listener in [ x for x in listeners if x.socktype in ['SSL', 'TCP'] ]:
         redir.add_forwarding("tcp", listener.ports)
     # pass through any explicitly excluded ports
-    exclusions = config.cfg.get("redirection", "port_exclusions")
+    exclusions = list(parseints(config.cfg.get("redirection", "port_exclusions")))
     if exclusions:
-        redir.add_forwarding("tcp", exclusions.split(","))
+        redir.add_forwarding("tcp", exclusions)
     # forward all other ports to generic listener
     generic = config.cfg.get("redirection", "port_forwarding")
     if generic:
